translate.misc.wStringIO

Package translate :: Package misc :: Module wStringIO |
[hide private]
[frames] | no frames]

# Module wStringIO

source code

A wrapper for cStringIO that provides more of the functions of StringIO at the speed of cStringIO

Classes | [hide private]
| StringIO
| CatchStringOutput catches the output before it is closed and sends it to an onclose method

Variables | [hide private]
| __package__ = ``'``translate.misc``'``

Imports: cStringIO